# Project Authors

The following people have made contributions to the project (in alphabetical order by
last name) and are considered "The RockHound Developers":

* [Santiago Soler](https://github.com/santisoler)
* [Leonardo Uieda](https://github.com/leouieda)
